//-----------------------------------------------------------------------------
//    Package Definition
//-----------------------------------------------------------------------------
package uicc.usim.test.toolkit.api_2_tkr_sevl;

//-----------------------------------------------------------------------------
//  Imports
//-----------------------------------------------------------------------------
import org.etsi.scp.wg3.uicc.jcapi.userinterface.*;
import org.etsi.scp.wg3.uicc.jcapi.userclass.*;
import org._3gpp.ct.wg6.usim.jcapi.userclass.*;
import org._3gpp.ct.wg6.usim.jcapi.userinterface.*;

public class Test_Api_2_Tkr_Sevl extends UiccTestModel {
    
    static final String CAP_FILE_PATH = "uicc/usim/test/toolkit/api_2_tkr_sevl";
    static final String CLASS_AID_1 = "A0000000 871005FF FFFFFF89 20010001";
    static final String APPLET_AID_1 = "A0000000 871005FF FFFFFF89 20010102";
    static final String CLASS_AID_2 = "A0000000 871005FF FFFFFF89 20020001";
    static final String APPLET_AID_2 = "A0000000 871005FF FFFFFF89 20020102";
    static final String CLASS_AID_3 = "A0000000 871005FF FFFFFF89 01";
    static final String APPLET_AID_3 = "A0000000 871005FF FFFFFF89 02";
    
    
    private USimAPITestCardService test;
    APDUResponse response;
    
    
    public Test_Api_2_Tkr_Sevl() {
        test = USimAPITestCardService.getTheUSimTestCardService();
    }
    
    public boolean run() {
        boolean result = false;
        
        // test script
        test.reset();
        test.terminalProfileSession("1719");
        
        // Install package
        test.loadPackage(CAP_FILE_PATH);
        
        // Install Applet1
        test.installApplet(CAP_FILE_PATH, CLASS_AID_1, APPLET_AID_1,
                "8008" + // TLV UICC Toolkit application specific parameters
                "01" +   // V Priority Level
                "00" +   // V Max. number of timers
                "00" +   // V Maximum text length for a menu entry
                "00" +   // V Maximum number of menu entries
                "00" +   // V Maximum number of channels
                "00" +   // LV Minimum Security Level field
                "00" +   // LV TAR Value(s)
                "00" );  // V Maximum number of services
        
        // Install Applet2
        test.installApplet(CAP_FILE_PATH, CLASS_AID_2, APPLET_AID_2,
                "8008" + // TLV UICC Toolkit application specific parameters
                "01" +   // V Priority Level
                "00" +   // V Max. number of timers
                "00" +   // V Maximum text length for a menu entry
                "00" +   // V Maximum number of menu entries
                "00" +   // V Maximum number of channels
                "00" +   // LV Minimum Security Level field
                "00" +   // LV TAR Value(s)
                "00" );  // V Maximum number of services
        
        // Install Applet3
        test.installApplet(CAP_FILE_PATH, CLASS_AID_3, APPLET_AID_3,
                "8008" + // TLV UICC Toolkit application specific parameters
                "01" +   // V Priority Level
                "00" +   // V Max. number of timers
                "00" +   // V Maximum text length for a menu entry
                "00" +   // V Maximum number of menu entries
                "00" +   // V Maximum number of channels
                "00" +   // LV Minimum Security Level field
                "00" +   // LV TAR Value(s)
                "00" );  // V Maximum number of services
        
        test.reset();
        test.terminalProfileSession("1719");
        
        /*********************************************************************/
        /** Testcase 1. Applet1 Registers all eventList buffer                   */
        /** Testcase 2. Registering part of eventList buffer                   */
        /** Testcase 3. Setting EVENT_MO_SHORT_MESSAGE_CONTROL_BY_SIM        */
        /*********************************************************************/
        
        //Trigger applet1 (formatted sms pp envelope)
        test.envelopeSmsPp("0B254008 81556677 887FF600 11291200" +
                "00041402 7000000F 0D080000 00200101" +
                "00000000 010000");
        
        /*********************************************************************/
        /** Testcase 4.Check applet1 is triggered by an ENVELOPE              */
        /** (EVENT_MO_SHORT_MESSAGE_CONTROL_BY_SIM)                          */
        /*********************************************************************/
        test.reset();
        test.terminalProfileSession("1719");
        
        //Trigger applet1
        test.envelopeMoShortMessageControl();
        
        /*********************************************************************/
        /** Testcase 5.Applet2 registers to                                  */
        /** EVENT_MO_SHORT_MESSAGE_CONTROL_BY_SIM but it is already assigned */
        /*********************************************************************/
        
        //Trigger applet2 (formatted sms pp envelope)
        test.envelopeSmsPp("0B254008 81556677 887FF600 11291200" +
                "00041402 7000000F 0D080000 00200201" +
                "00000000 010000");
        
        /*********************************************************************/
        /** Testcase 6.Applet2 registers to                                  */
        /** EVENT_MO_SHORT_MESSAGE_CONTROL_BY_SIM but it is already assigned */
        /** to another applet in not selectable state                        */
        /*********************************************************************/
        
        // Set the applet1 in the lock state
        test.lockApplication(APPLET_AID_1);
        
        //Trigger applet2 (formatted sms pp envelope)
        test.envelopeSmsPp("0B254008 81556677 887FF600 11291200" +
                "00041402 7000000F 0D080000 00200201" +
                "00000000 010000");
        
        // Set the applet1 in the make selectable state
        test.unlockApplication(APPLET_AID_1);
        
        
        /*********************************************************************/
        /** Testcase 7.Applet3 with no TAR defined registers to              */
        /** EVENT_UNFORMATTED_SMS_CB event                                   */
        /*********************************************************************/
                
        //Trigger applet
        test.envelopeCellBroadcast("0C580001 10010011 00000000 00000000" +
                "00000000 00000000 00000000 00000000" +
                "00000000 00000000 00000000 00000000" +
                "00000000 00000000 00000000 00000000" +
                "00000000 00000000 00000000 00000000" +
                "00000000 00000000 0000");
        
        
        /***********************************/
        /**         Check results          */
        /***********************************/
        
        // Select applet1
        response = test.selectApplication(APPLET_AID_1);
        result = response.checkData("10" + APPLET_AID_1 +
                "04CCCCCC CC");
        
        // Select applet2
        response = test.selectApplication(APPLET_AID_2);
        result &= response.checkData("10" + APPLET_AID_2 +
                "02CCCC");
        
        // Select applet3
        response = test.selectApplication(APPLET_AID_3);
        result &= response.checkData("0D" + APPLET_AID_3 +
                "07CCCCCC CCCCCCCC");
        
        
        test.reset();
        test.terminalProfileSession("1719");
        // Delete Applet1
        test.deleteApplet(APPLET_AID_1);
        // Delete Applet2
        test.deleteApplet(APPLET_AID_2);
        // Delete Applet3
        test.deleteApplet(APPLET_AID_3);
        // Delete Package
        test.deletePackage(CAP_FILE_PATH);
        
        return result;
    }
}
