//-----------------------------------------------------------------------------
//Package Definition
//-----------------------------------------------------------------------------
package uicc.usim.test.toolkit.api_2_ueh_gsmo;

//-----------------------------------------------------------------------------
//Imports
//-----------------------------------------------------------------------------
import org.etsi.scp.wg3.uicc.jcapi.userinterface.*;
import org.etsi.scp.wg3.uicc.jcapi.userclass.*;
import org._3gpp.ct.wg6.usim.jcapi.userclass.*;

public class Test_Api_2_Ueh_Gsmo extends UiccTestModel {
    
    static final String CAP_FILE_PATH = "uicc/usim/test/toolkit/api_2_ueh_gsmo";
    static final String CLASS_AID_1 = "A0000000 871005FF FFFFFF89 20010001";
    static final String APPLET_AID_1 = "A0000000 871005FF FFFFFF89 20010102";
    
    
    private USimAPITestCardService test;
    APDUResponse response;
    
        
    public Test_Api_2_Ueh_Gsmo() {
        test = USimAPITestCardService.getTheUSimTestCardService();
    }
    
    public boolean run() {
        boolean result = false;
        
        // test script
        test.reset();
        test.terminalProfileSession("1719");
        
        
        // Install package
        test.loadPackage(CAP_FILE_PATH);
            
        // Install Applet
        test.installApplet(CAP_FILE_PATH, CLASS_AID_1, APPLET_AID_1, 
            "8008" + // TLV UICC Toolkit application specific parameters
                "01" +   // V Priority Level
                "00" +   // V Max. number of timers
                "00" +   // V Maximum text length for a menu entry
                "00" +   // V Maximum number of menu entries                              
                "00" +   // V Maximum number of channels 
                "00" +   // LV Minimum Security Level field
                "00" +   // LV TAR Value(s) 
                "00" );  // V Maximum number of services
        
        test.reset();
        test.terminalProfileSession("1719");
        
        // Testcase 1. Test with TP-OA length of 2 and RC/CC/DS length is 0 
        test.envelopeSmsPp( "8B4B4002 81557FF6 00112912 0000043D" +
                            "02700000 380D0800 00002001 01000000" +
                            "00010011 22334455 66778899 10111213" +
                            "14151617 18191A1B 1C1D1E1F 20212223" +
                            "24252627 28292A2B 2C2D2E2F 30");
        
        
        // Testcase 2. Test with TP-OA length of 12 and RC/CC/DS length is 0 
        test.envelopeSmsPp( "8B50400C 81334455 6677887F F6001129" +
                            "12000004 3D027000 00380D08 00000020" +
                            "01010000 00000100 11223344 55667788" +
                            "99101112 13141516 1718191A 1B1C1D1E" +
                            "1F202122 23242526 2728292A 2B2C2D2E" +
                            "2F30");
        
        // Testcase 3. Test with RC/CC/DS length of 8 and TP-OA length is 2 
        test.envelopeSmsPp( "8B394002 81557FF6 00112912 0000042B" +
                            "02700000 26150A02 00112001 01000000" +
						    "00010070 C8F096D3 2674EE10 11121314" +
                            "15161718 191A1B1C 1D1E1F");
        
        // Testcase 4. Send a SMS PP with 2 TPDU TLV and inside two different secured data offsets 0                                 
        test.envelopeSmsPp( "8B294008 81556677 887FF600 11291200" +
                            "00041802 70000013 0D080000 00200101" +
                            "00000000 01000102 0304058B 2C400281" +
                            "557FF600 11291200 00041D02 70000018" +
                            "0D080000 00100101 00000000 00010001" +
                            "02030405 06070809 0A");
        
        // Testcase 5. Same test as     CASE 1 but without any secured data    
        test.envelopeSmsPp( "8B214002 81557FF6 00112912 00000413" +
                            "02700000 0E0D0800 00002001 01000000" +
                            "000100");
        
        // Testcase 6. Test with FORMATTED_SMS_PP ENV Verify after call     
        // of the method the current TLV is the TPDU TLV: findTLV device     
        // identities, getSecuredDataOffset and then getValueByte to verify 
        // that the current TLV is the TPDU TLV                             
        test.envelopeSmsPp( "8B294008 81556677 887FF600 11291200" +
                            "00041802 70000013 0D080000 00200101" +
                            "00000000 01001011 121314");
        
        // Testcase 7-1.  Concatenated SMS with maximum user data            
        // length = 0x10D Secured data length = 0xFA                                              
        // 1st envelope                                                     
        response = test.envelopeSmsPp(
            "8B819D40 08815566 77887FF6 00112912" +
            "0000048C 07000300 02017000 01080D08" +
            "00000020 01010000 00000100 01020304" +
            "05060708 090A0B0C 0D0E0F10 11121314" +
            "15161718 191A1B1C 1D1E1F20 21222324" +
            "25262728 292A2B2C 2D2E2F30 31323334" +
            "35363738 393A3B3C 3D3E3F40 41424344" +
            "45464748 494A4B4C 4D4E4F50 51525354" +
            "55565758 595A5B5C 5D5E5F60 61626364" +
            "65666768 696A6B6C 6D6E6F70 71727374");

        response = test.envelopeSmsPp(
            "8B819D40 08815566 77887FF6 00112912" +
            "0000048C 05000300 02027576 7778797A" +
            "7B7C7D7E 7F808182 83848586 8788898A" +
            "8B8C8D8E 8F909192 93949596 9798999A" +
            "9B9C9D9E 9FA0A1A2 A3A4A5A6 A7A8A9AA" +
            "ABACADAE AFB0B1B2 B3B4B5B6 B7B8B9BA" +
            "BBBCBDBE BFC0C1C2 C3C4C5C6 C7C8C9CA" +
            "CBCCCDCE CFD0D1D2 D3D4D5D6 D7D8D9DA" +
            "DBDCDDDE DFE0E1E2 E3E4E5E6 E7E8E9EA" +
            "EBECEDEE EFF0F1F2 F3F4F5F6 F7F8F9FA");

        /*********************************************************************/
        /** FORMATTED SMS PP UPD Triggering                                  */
        /*********************************************************************/
        //select EF SMS
        test.selectFile("3F00");
        test.selectFile("7F10");
        test.selectFile("6F3C");
        
        // Testcase 8.  Same test as 1 but with FORMATTED_SMS_PP_UPD                     
        //update first record
        test.updateRecord(  "01", "04", 
                            "03058011 22334440 0281557F F6001129" +
                            "12000004 3D027000 00380D08 00000020" +
                            "01010000 00000100 11223344 55667788" +
                            "99101112 13141516 1718191A 1B1C1D1E" +
                            "1F202422 23242526 2728292A 2B2C2D2E" +
                            "2F30FFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF");
          
        // Testcase 9.  Same test as 2 but with FORMATTED_SMS_PP_UPD                     
        test.updateRecord(  "01", "04", 
                            "03058011 22334440 0C813344 55667788" +
                            "7FF60011 29120000 043D0270 0000380D" +
                            "08000000 20010100 00000001 00112233" +
                            "44556677 88991011 12131415 16171819" +
                            "1A1B1C1D 1E1F2021 22232425 26272829" +
                            "2A2B2C2D 2E2F30FF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF");
        
        // Testcase 10.  Same test as 3 but with FORMATTED_SMS_PP_UPD                      
       test.updateRecord(   "01", "04", 
                            "03058011 22334440 0281557F F6001129" +
                            "12000004 2B027000 0026150A 02001120" +
                            "01010000 00000100 70C8F096 D32674EE" +
                            "10111213 14151617 18191A1B 1C1D1E1F" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF");
        
        // Testcase 11.  Send a SMS PP with 2 TPDU TLV and inside two different secured data offsets                     
        test.updateRecord(  "01", "04", 
                            "03058011 22334440 08815566 77887FF6" +
                            "00112912 00000418 02700000 130D0800" +
                            "00002001 01000000 00010001 02030405" +
                            "40028155 7FF60011 29120000 041D0270" +
                            "0000180D 08000000 20010100 00000001" +
                            "00010203 04050607 08090AFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF ");
        
        // Testcase 12.  Same test as 5 but with FORMATTED_SMS_PP_UPD                       
        test.updateRecord(  "01", "04", 
                            "03058011 22334440 0281557F F6001129" +
                            "12000004 13027000 000E0D08 00000020" +
                            "01010000 00000100 FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF");
        
        // Testcase 13.  Test with FORMATTED_SMS_PP UPD Verify after call   
        // of the method the current TLV is the TPDU TLV: findTLV device    
        // identities, getSecuredDataOffset and then getValueByte to verify 
        // that the current TLV is the TPDU TLV                              
        test.updateRecord(  "01", "04", 
                            "03058011 22334440 0281557F F6001129" +
                            "12000004 13027000 000E0D08 00000020" +
                            "01010000 00000100 FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF");
        
        
        // Testcase 14-1.  Same test as 8, but with a concatenated SMS          
        // (2 Short Messages and maximum Secured Data Length = 0x00FA)                   
        test.updateRecord(  "01", "04", 
                            "03058011 22334440 0281557F F6001129" +
                            "12000004 8C070003 00020170 0001080D" +
						    "08000000 20010100 00000001 00010203" +
						    "04050607 08090A0B 0C0D0E0F 10111213" +
						    "14151617 18191A1B 1C1D1E1F 20212223" +
						    "24252627 28292A2B 2C2D2E2F 30313233" +
						    "34353637 38393A3B 3C3D3E3F 40414243" +
						    "44454647 48494A4B 4C4D4E4F 50515253" +
						    "54555657 58595A5B 5C5D5E5F 60616263" +
						    "64656667 68696A6B 6C6D6E6F 70717273" +
                            "74FFFFFF FFFFFFFF FFFFFFFF FFFFFFFF");

        // 2nd Update record  
        test.updateRecord(  "01", "04", 
                            "03058011 22334440 0281557F F6001129" +
                            "12000004 8C050003 00020275 76777879" +
						    "7A7B7C7D 7E7F8081 82838485 86878889" +
						    "8A8B8C8D 8E8F9091 92939495 96979899" +
						    "9A9B9C9D 9E9FA0A1 A2A3A4A5 A6A7A8A9" +
						    "AAABACAD AEAFB0B1 B2B3B4B5 B6B7B8B9" +
						    "BABBBCBD BEBFC0C1 C2C3C4C5 C6C7C8C9" +
						    "CACBCCCD CECFD0D1 D2D3D4D5 D6D7D8D9" +
						    "DADBDCDD DEDFE0E1 E2E3E4E5 E6E7E8E9" +
						    "EAEBECED EEEFF0F1 F2F3F4F5 F6F7F8F9" +
                            "FAFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF");
        
        /*********************************************************************/
        /** FORMATTED SMS CB Triggering                                      */
        /*********************************************************************/
        // Testcase 15. Same test as 1 but with FORMATTED_SMS_CB             
        test.envelopeCellBroadcast( "0C580000 1080F611 001E0D08 00000020" +
                                    "01010000 00000100 11223344 55667788" +
                                    "11223344 55667788 00000000 00000000" +
                                    "00000000 00000000 00000000 00000000" +
                                    "00000000 00000000 00000000 00000000" +
                                    "00000000 00000000 0000");
        
        // Testcase 16. Same test as 3 but with FORMATTED_SMS_CB            
        test.envelopeCellBroadcast( "0C580000 1080F611 0026150A 00001120" +
                                    "01010000 00000100 B737577A C22A601A" +
                                    "11223344 55667788 11223344 55667788" +
                                    "00000000 00000000 00000000 00000000" +
                                    "00000000 00000000 00000000 00000000" +
                                    "00000000 00000000 0000");
        
        // Testcase 17. Same test as 5 but with FORMATTED_SMS_CB            
        test.envelopeCellBroadcast( "0C580000 1080F611 000E0D08 00000020" +
                                    "01010000 00000100 00000000 00000000" +
                                    "00000000 00000000 00000000 00000000" +
                                    "00000000 00000000 00000000 00000000" +
                                    "00000000 00000000 00000000 00000000" +
                                    "00000000 00000000 0000");
        
        // Testcase 18. Test with FORMATTED_SMS_CB Verify after call of     
        // the method the current TLV is the Cell Broadcast Page TLV:       
        // FindTLV() device identities, getSecuredDataOffset() and then     
        // getValueByte() to verify that the current TLV is the Cell        
        // Broadcast Page TLV                                               
        test.envelopeCellBroadcast( "0C580000 1080F611 000E0D08 00000020" +
                                    "01010000 00000100 00000000 00000000" +
                                    "00000000 00000000 00000000 00000000" +
                                    "00000000 00000000 00000000 00000000" +
                                    "00000000 00000000 00000000 00000000" +
                                    "00000000 00000000 0000");
        
        /*********************************************************************/
        /** Unformatted Envelope Triggering                                    */
        /*********************************************************************/
        
        // Testcase 19. Send an UNFORMATTED SMS PP envelope with TP-OA,     
        // length = 2                                                                    
        test.envelopeSmsPp( "8B4B0002 81557FF6 00112912 0000043D" +
                            "11223344 55667788 99101112 13141516" +
                            "1718191A 1B1C1D1E 1F202122 23242526" +
                            "2728292A 2B2C2D2E 2F303132 33343536" +
                            "3738393A 3B3C3D3E 3F404142 43");
        
        
        // Testcase 20. Send an UNFORMATTED SMS PP envelope with TP-OA,     
        // length = 12                                                                    
        test.envelopeSmsPp( "8B50000C 81334455 6677887F F6001129" +
                            "12000004 3D112233 44556677 88991011" +
                            "12131415 16171819 1A1B1C1D 1E1F2021" +
                            "22232425 26272829 2A2B2C2D 2E2F3031" +
                            "32333435 36373839 3A3B3C3D 3E3F4041" +
                            "4243");
        
        // Testcase 21. Send a SMS PP with 2 TPDU TLV and inside two        
        // different UDL offsets                                            
        test.envelopeSmsPp( "8B160008 81556677 887FF600 11291200" +
                            "00040501 02030405 8B1B4008 81556677" +
                            "887FF600 11291200 00040A01 02030405" +
                            "06070809 0A");  
        
        
        // Testcase 22. Test with UNFORMATTED_SMS_PP ENV Verify after call   
        // of the method the current TLV is the TPDU TLV: findTLV device     
        // identities, getSecuredDataOffset and then getValueByte to verify 
        // that the current TLV is the TPDU TLV                             
        test.envelopeSmsPp( "8B160008 81556677 887FF600 11291200" +
                            "00040510 11121314");
        
        // Testcase 23.  Concatenated SMS with maximum user data length = 0x10C         
        // 1st envelope                                                     
        test.envelopeSmsPp( "8B819A40 0281557F F6001129 12000004" +
                            "8C050003 03020101 02030405 06070809" +
                            "0A0B0C0D 0E0F1011 12131415 16171819" +
                            "1A1B1C1D 1E1F2021 22232425 26272829" +
                            "2A2B2C2D 2E2F3031 32333435 36373839" +
                            "3A3B3C3D 3E3F4041 42434445 46474849" +
                            "4A4B4C4D 4E4F5051 52535455 56575859" +
                            "5A5B5C5D 5E5F6061 62636465 66676869" +
                            "6A6B6C6D 6E6F7071 72737475 76777879" +
                            "7A7B7C7D 7E7F8081 82838485 86");
        // 2nd envelope 
        test.envelopeSmsPp( "8B819A40 0281557F F6001129 12000004" +
                            "8C050003 03020287 88898A8B 8C8D8E8F" +
                            "90919293 94959697 98999A9B 9C9D9E9F" +
                            "A0A1A2A3 A4A5A6A7 A8A9AAAB ACADAEAF" +
                            "B0B1B2B3 B4B5B6B7 B8B9BABB BCBDBEBF" +
                            "C0C1C2C3 C4C5C6C7 C8C9CACB CCCDCECF" +
                            "D0D1D2D3 D4D5D6D7 D8D9DADB DCDDDEDF" +
                            "E0E1E2E3 E4E5E6E7 E8E9EAEB ECEDEEEF" +
                            "F0F1F2F3 F4F5F6F7 F8F9FAFB FCFDFEFF" +
                            "00010203 04050607 08090A0B 0C");
        
        /*********************************************************************/
        /** UNFORMATTED SMS PP UPD Triggering                               */
        /*********************************************************************/
        // Testcase 24.  Same test as 18 but with UNFORMATTED_SMS_PP_UPD                       
        test.updateRecord(  "01", "04", 
                            "03058011 22334400 0281557F F6001129" + 
                            "12000004 3D112233 44556677 88991011" +
                            "12131415 16171819 1A1B1C1D 1E1F2021" +
                            "22232425 26272829 2A2B2C2D 2E2F3031" +
                            "32333435 36373839 3A3B3C3D FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF");
        
        
        // Testcase 25.  Same test as 29 but with UNFORMATTED_SMS_PP_UPD                              
        test.updateRecord(  "01", "04", 
                            "03058011 22334400 0C813344 55667788" +
                            "7FF60011 29120000 043D1122 33445566" +
                            "77889910 11121314 15161718 191A1B1C" +
                            "1D1E1F20 21222324 25262728 292A2B2C" +
                            "2D2E2F30 31323334 35363738 393A3B3C" +
                            "3DFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF");
        
        // Testcase 26.  Same test as 19 but with UNFORMATTED_SMS_PP_UPD                      
       test.updateRecord(  "01", "04", 
                            "03058011 22334400 08815566 77887FF6" +
                            "00112912 00000418 01020304 05060708" +
                            "090A0B0C 0D0E0F10 11121314 15161718" +
                            "00088155 6677887F F6001129 12000004" +
                            "23010203 04050607 08090A0B 0C0D0E0F" +
                            "10111213 14151617 18191A1B 1C1D1E1F" +
                            "20212223 FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF");
        
        //Testcase 27.  Test with UNFORMATTED_SMS_UPD                       
        // Verify after call of the method the current TLV is the TPDU TLV: 
        // findTLV device identities, getShortMessageOffset and then        
        // getValueByte to verify that the current TLV is the TPDU TLV                     
        test.updateRecord(  "01", "04", 
                            "03058011 22334400 08815566" +
                            "77887FF6 00112912 00000405 10111213" +
                            "14FFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF" +
                            "FFFFFFFF ");
        
        
        // Testcase 28.  Same test as 24, but with a concatenated SMS       
        // (2 Short Messages and maximum Secured Data Length = 0x00FA)                     
        //update first record
        test.updateRecord(  "01", "04", 
                            "03058011 22334440 0281557F F6001129" +
                            "12000004 8C050003 02020101 02030405" +
                            "06070809 0A0B0C0D 0E0F1011 12131415" +
                            "16171819 1A1B1C1D 1E1F2021 22232425" +
                            "26272829 2A2B2C2D 2E2F3031 32333435" +
                            "36373839 3A3B3C3D 3E3F4041 42434445" +
                            "46474849 4A4B4C4D 4E4F5051 52535455" +
                            "56575859 5A5B5C5D 5E5F6061 62636465" +
                            "66676869 6A6B6C6D 6E6F7071 72737475" +
                            "76777879 7A7B7C7D 7E7F8081 82838485" +
                            "86FFFFFF FFFFFFFF FFFFFFFF FFFFFFFF");
        
        
        // 2nd Update record  
        test.updateRecord(  "01", "04", 
                            "03058011 22334440 0281557F F6001129" +
                            "12000004 8C050003 02020287 88898A8B" +
                            "8C8D8E8F 90919293 94959697 98999A9B" +
                            "9C9D9E9F A0A1A2A3 A4A5A6A7 A8A9AAAB" +
                            "ACADAEAF B0B1B2B3 B4B5B6B7 B8B9BABB" +
                            "BCBDBEBF C0C1C2C3 C4C5C6C7 C8C9CACB" +
                            "CCCDCECF D0D1D2D3 D4D5D6D7 D8D9DADB" +
                            "DCDDDEDF E0E1E2E3 E4E5E6E7 E8E9EAEB" +
                            "ECEDEEEF F0F1F2F3 F4F5F6F7 F8F9FAFB" +
                            "FCFDFEFF 00010203 04050607 08090A0B" +
                            "0CFFFFFF FFFFFFFF FFFFFFFF FFFFFFFF");                                 
        
        
        /*********************************************************************/
        /** UNFORMATTED SMS CB Triggering                                    */
        /*********************************************************************/
        // Testcase 29 Send an UNFORMATTED SMS CB envelope                    
        test.envelopeCellBroadcast( "0C580000 1000F611 10111213 14151617" +
                                    "18191A1B 1C1D1E1F 00000000 00000000" +
                                    "00000000 00000000 00000000 00000000" +
                                    "00000000 00000000 00000000 00000000" +
                                    "00000000 00000000 00000000 00000000" +
                                    "00000000 00000000 0000"); 
        
        // Testcase 30 Send envelope SMS-CB UnFormatted.FindTLV() with        
        // TAG_DEVICE_IDENTITIES. getShortMessageOffset() and then getValueByte() with offset 0                                       
        test.envelopeCellBroadcast( "0C580000 1000F611 10111213 14151617" +
                                    "18191A1B 1C1D1E1F 00000000 00000000" +
                                    "00000000 00000000 00000000 00000000" +
                                    "00000000 00000000 00000000 00000000" +
                                    "00000000 00000000 00000000 00000000" +
                                    "00000000 00000000 0000"); 
        
        // Testcase 31 Send an Unrecognized Envelope with neither TPDU TLV   
        // nor Cell Broadcast Page TLV, then call the method.               
        test.unrecognizedEnvelope();
          
        
        /***********************************/        
        /**         Check results          */        
        /***********************************/         
        
        // Select applet
        response = test.selectApplication(APPLET_AID_1);
        result = response.checkData("10" + APPLET_AID_1 + 
                                    "1FCCCCCC CCCCCCCC CCCCCCCC CCCCCCCC" +
                                    "CCCCCCCC CCCCCCCC CCCCCCCC CCCCCCCC");
                                    
        
        test.reset();
        test.terminalProfileSession("1719");
                                           
        // Delete Applet 
        test.deleteApplet(APPLET_AID_1);
        // Delete Package
        test.deletePackage(CAP_FILE_PATH);   
      
      return result;
    }
}   
